function [LOD,LOQ] = fct_LOD(x,y,mdl,yB)
% Test data: 
% x = 1:10;
% y = [5,6,6,6,7,7,8,8,10,10];
% mdl : linear model to data (if already existent, don't recalculate)
% yB : Blank value of calibration (y(x=0)); if not given := 0

if nargin<2
    error('Please provide x and y vectors for LoD calculation')
end

if ~exist('yB','var')
    yB = 0;
end

% Fit linear model if not existent (for comparison excel, we would neet the
% intercept to be true (b and m calculated). But this does not fit our
% twofold interpolation 

if ~exist('mdl','var')
    mdl = fitlm(x,y,'intercept',true);
    
    b    = mdl.Coefficients.Estimate(1);
    m    = mdl.Coefficients.Estimate(2);
    RMSE = mdl.RMSE;
else
    b    = 0;
    m    = mdl.Coefficients.Estimate(1);
    RMSE = mdl.RMSE;
end


% Reshape to vector in column format
x = reshape(x,[],1);
y = reshape(y,[],1);
xmin = min(x);
xmax = max(x);

yRed = y-yB;
yRedMean = mean(yRed);


% Calculate main statistics
n = length(x);
t = tinv(0.975,n-2);
xvar = var(x,1);
xmean  = mean(x);

% Calculate helper values
xc =       RMSE * t/m  * sqrt( 1+1/n+ xmean^2     / (xvar*n));
yc = b +   RMSE * t    * sqrt( 1+1/n+ xmean^2     / (xvar*n));
yh = b + 2*RMSE * t    * sqrt( 1+1/n+(xc-xmean)^2 / (xvar*n));

% Calculate Limit of Detection and Limit of Quantification
LOD =         2 * RMSE*t/m *sqrt( 1+1/n+ (yc-yRedMean)^2/(xvar*n*m^2));
LOQ = (yh-b)/m+   RMSE*t/m *sqrt( 1+1/n+ (yh-yRedMean)^2/(xvar*n*m^2));
%{
if LOD < xmin
   warning('LOD below calibrated range')
elseif LOD > xmax    
   warning('LOD above calibrated range')
end
if LOQ < xmin
    warning('LOQ below calibrated range')
elseif LOQ > xmax
    warning('LOQ above calibrated range')
%}
end
