function [cmap,minData,maxData] = fct_colormap(data,cmap_step,type,minmax)
% Yields data-fitted colormap, ignoring outliers

    data_outlier = isoutlier(data,'movmedian',[10,10]);
    data(data_outlier) = [];
    
    if strcmp(type,'min')
        minData = nanmin([0,data],[],'all');
        maxData = nanmax([0,data],[],'all');
    elseif strcmp(type,'mean')
        minData = nanmean([0,data(data<0)]);
        maxData = nanmean([0,data(data>0)]);
    end

    if ~isempty(cmap_step)
        minData = floor(minData./cmap_step).*cmap_step;
        maxData = ceil( maxData./cmap_step).*cmap_step;
    end
    
    if exist('minmax','var')
        minData = min(minmax);
        maxData = max(minmax);
    end
    
    sumOfSigns = nansum([sign(minData),sign(maxData)]);
    if sumOfSigns < 0       % All velocities negative
        cmap = flipud(spring(256));      
        
    elseif sumOfSigns > 0   % All velocities positive
        cmap = flipud(winter(256));  
        
    else      % Sign switch
        nr_neg = max(1,round(256*abs(minData)/(maxData-minData))); % Colors in negative
        nr_pos = max(1,round(256*abs(maxData)/(maxData-minData))); % Colors in positive
        
        %cmap = [spring(nr_neg);flipud(winter(nr_pos))];
        cmap = [(fct_cmap_var(nr_neg,0,1)); flipud(fct_cmap_var(nr_pos,0.67,1))];
    end
    
    cmap(1,:) = [1 1 1]; % White for nan
end