% Jan-Pascal Boos, University of Bayreuth, Germany, 2023
% Available online: DOI: 10.5281/zenodo.10083568

%% Compare bedform elevation / metrics of different experiments
clear all; close all; clc

exp_date    = {'220727', '220803', '210812', '220818',   '220901'}';
exp_text = {'1 m',   '3 m',   '10 m',  'fine sand','high flow'};

exp_name = string(strcat('exp',exp_date));
pfad     = fct_pfad(char(exp_date));
qty_Exp  = length(exp_date); 

%% Read experiment results
for i = 1:qty_Exp
    expFile = strcat(pfad.results(i,:),exp_date{i},'-profiler.mat');
    exp_i = ['exp',exp_date{i}];
    expData.(exp_i) = load(expFile,'-mat');
end

%% Extract elevations and metrics of individual datasets
for i = 1 : qty_Exp
    x(:,i)         = expData.(exp_name(i)).x_interp;
    z(:,i)         = expData.(exp_name(i)).z_interp_mmean;
    rippleAmp(:,i) = expData.(exp_name(i)).ripple_amp;
    rippleLen(:,i) = expData.(exp_name(i)).ripple_len;
    rippleT2C(:,i) = expData.(exp_name(i)).ripple_t2cPerctg;
end

rippleAmpMean = mean(rippleAmp,1).';
rippleLenMean = mean(rippleLen,1).';
rippleT2CMean = mean(rippleT2C,1).';

% Exporting x-grid and sediment elevations (median + movmean (10)
export_profile = [exp_name'; exp_text; rippleLenMean'; rippleT2CMean'; rippleAmpMean'];
fullfilename = strcat(pfad.comparison,'profiler_bedforms.dat');

fileID = fopen(fullfilename,'w');
fprintf(fileID,'Bedform metrics comparison\n');
fprintf(fileID,'exp_date\texp_name\trippleLength\trippleT2C\trippleAmp\n');
fprintf(fileID,'%s\t%s\t%4.1f\t%4.1f\t%4.1f\n',export_profile);
fclose(fileID);

% Print some results
clear res
res{1} = sprintf('Comparison of maximum of normalized mass transfer rates, compared to 1 m');
res{2} = sprintf('Experiments: %s, %s, %s, %s, %s\n',exp_text{:});
res{3} = sprintf('Ripple amplitude [mm]:  %.0f, %.0f, %.0f, %.0f, %.0f, (%.0f)',rippleAmpMean, mean(rippleAmpMean));
res{4} = sprintf('Ripple Length [mm]: %.0f, %.0f, %.0f, %.0f, %.0f, (%.0f)',rippleLenMean, mean(rippleLenMean));
res{5} = sprintf('Ripple Trough-to-Crest ratio [%%]: %.0f, %.0f, %.0f, %.0f, %.0f, (%.0f)',rippleT2CMean, mean(rippleT2CMean));
msgbox(res,'Profiler metrics')

%% Compare elevations
figure
hold all
for i = 1 : qty_Exp
    plot(x(:,i), z(:,i),'LineWidth',2,'DisplayName',exp_text{i})
end
legend
xlim([2400,4900])
ylim([100,150])

set(gcf,'units','normalized','position',[0,0.25,1,0.5])
set(findall(gcf,'-property','FontSize'),'FontSize',11)

fullfilename = strcat(pfad.comparison,'profiler_comparison');
print('-r300',fullfilename,'-dpng')

%EOF